Method: TweetStream::Client#track

Defined in:
lib/tweetstream/client.rb

#track(*keywords, &block) ⇒ Object

Specify keywords to track. Queries are subject to Track Limitations, described in Track Limiting and subject to access roles, described in the statuses/filter method. Track keywords are case-insensitive logical ORs. Terms are exact-matched, and also exact-matched ignoring punctuation. Phrases, keywords with spaces, are not supported. Keywords containing punctuation will only exact match tokens. Query parameters may be passed as the last argument.



103
104
105
106
# File 'lib/tweetstream/client.rb', line 103

def track(*keywords, &block)
  query = TweetStream::Arguments.new(keywords)
  filter(query.options.merge(:track => query), &block)
end