Method: TweetStream::Client#filter
- Defined in:
- lib/tweetstream/client.rb
#filter(query_params = {}, &block) ⇒ Object
Make a call to the statuses/filter method of the Streaming API, you may provide :follow, :track or both as options to follow the tweets of specified users or track keywords. This method is provided separately for cases when it would conserve the number of HTTP connections to combine track and follow.
135 136 137 |
# File 'lib/tweetstream/client.rb', line 135 def filter(query_params = {}, &block) start('/1.1/statuses/filter.json', query_params.merge(:method => :post), &block) end |